#ifndef _EFL_UI_GRID_STATIC_EO_H_
#define _EFL_UI_GRID_STATIC_EO_H_

#ifndef _EFL_UI_GRID_STATIC_EO_CLASS_TYPE
#define _EFL_UI_GRID_STATIC_EO_CLASS_TYPE

typedef Eo Efl_Ui_Grid_Static;

#endif

#ifndef _EFL_UI_GRID_STATIC_EO_TYPES
#define _EFL_UI_GRID_STATIC_EO_TYPES


#endif
/** Efl UI grid static class
 *
 * @ingroup Efl_Ui_Grid_Static
 */
#define EFL_UI_GRID_STATIC_CLASS efl_ui_grid_static_class_get()

EWAPI const Efl_Class *efl_ui_grid_static_class_get(void);

#endif
